@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Hook for HashiCorp Vault"""
+"""Hook for HashiCorp Vault."""
 from __future__ import annotations
 
 import json
@@ -366,7 +366,7 @@ class VaultHook(BaseHook):
 
     @classmethod
     def get_connection_form_widgets(cls) -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import BooleanField, IntegerField, StringField
@@ -403,14 +403,14 @@ class VaultHook(BaseHook):
 
     @staticmethod
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
             "hidden_fields": ["extra"],
             "relabeling": {},
         }
 
     def test_connection(self) -> tuple[bool, str]:
-        """Test Vault connectivity from UI"""
+        """Test Vault connectivity from UI."""
         try:
             self.get_conn()
             return True, "Connection successfully tested"
